@@ -5,11 +5,12 @@ from enum import Enum
 from typing import Optional
 
 import kubernetes
-from kubernetes.client.models import V1JobStatus
-
-from dagster import DagsterInstance
-from dagster import _check as check
+from dagster import (
+    DagsterInstance,
+    _check as check,
+)
 from dagster._core.storage.pipeline_run import DagsterRunStatus
+from kubernetes.client.models import V1JobStatus
 
 DEFAULT_WAIT_TIMEOUT = 86400.0  # 1 day
 DEFAULT_WAIT_BETWEEN_ATTEMPTS = 10.0  # 10 seconds
@@ -180,8 +181,7 @@ class DagsterKubernetesClient:
         while not job:
             if wait_timeout and (self.timer() - start > wait_timeout):
                 raise DagsterK8sTimeoutError(
-                    "Timed out while waiting for job {job_name}"
-                    " to launch".format(job_name=job_name)
+                    "Timed out while waiting for job {job_name} to launch".format(job_name=job_name)
                 )
 
             # Get all jobs in the namespace and find the matching job
@@ -192,9 +192,8 @@ class DagsterKubernetesClient:
                 if jobs.items:
                     check.invariant(
                         len(jobs.items) == 1,
-                        'There should only be one k8s job with name "{}", but got multiple jobs:" {}'.format(
-                            job_name, jobs.items
-                        ),
+                        'There should only be one k8s job with name "{}", but got multiple'
+                        ' jobs:" {}'.format(job_name, jobs.items),
                     )
                     return jobs.items[0]
                 else:
@@ -224,8 +223,9 @@ class DagsterKubernetesClient:
         while True:
             if wait_timeout and (self.timer() - start > wait_timeout):
                 raise DagsterK8sTimeoutError(
-                    "Timed out while waiting for job {job_name}"
-                    " to have pods".format(job_name=job_name)
+                    "Timed out while waiting for job {job_name} to have pods".format(
+                        job_name=job_name
+                    )
                 )
 
             pod_list = k8s_api_retry(_get_pods, max_retries=3, timeout=wait_time_between_attempts)
@@ -310,8 +310,9 @@ class DagsterKubernetesClient:
         while True:
             if wait_timeout and (self.timer() - start_time > wait_timeout):
                 raise DagsterK8sTimeoutError(
-                    "Timed out while waiting for job {job_name}"
-                    " to complete".format(job_name=job_name)
+                    "Timed out while waiting for job {job_name} to complete".format(
+                        job_name=job_name
+                    )
                 )
 
             # Reads the status of the specified job. Returns a V1Job object that
@@ -363,7 +364,10 @@ class DagsterKubernetesClient:
         job_name,
         namespace,
     ):
-        """Delete Kubernetes Job. We also need to delete corresponding pods due to:
+        """Delete Kubernetes Job.
+
+        We also need to delete corresponding pods due to:
+
         https://github.com/kubernetes-client/python/issues/234
 
         Args:
@@ -477,7 +481,6 @@ class DagsterKubernetesClient:
         start = start_time or self.timer()
 
         while True:
-
             pods = self.core_api.list_namespaced_pod(
                 namespace=namespace, field_selector="metadata.name=%s" % pod_name
             ).items
@@ -531,8 +534,8 @@ class DagsterKubernetesClient:
                     continue
                 if state.waiting.reason == KubernetesWaitingReasons.CreateContainerConfigError:
                     self.logger(
-                        'Pod "%s" is waiting due to a CreateContainerConfigError with message "%s" - trying again to see if it recovers'
-                        % (pod_name, state.waiting.message)
+                        'Pod "%s" is waiting due to a CreateContainerConfigError with message "%s"'
+                        " - trying again to see if it recovers" % (pod_name, state.waiting.message)
                     )
                     self.sleeper(wait_time_between_attempts)
                     continue
