@@ -1,11 +1,13 @@
 from typing import Iterator, List, Optional, cast
 
 import kubernetes
-from dagster_k8s.launcher import K8sRunLauncher
-
-from dagster import Field, IntSource, StringSource
-from dagster import _check as check
-from dagster import executor
+from dagster import (
+    Field,
+    IntSource,
+    StringSource,
+    _check as check,
+    executor,
+)
 from dagster._core.definitions.executor_definition import multiple_process_executor_requirements
 from dagster._core.errors import DagsterUnmetExecutorRequirementsError
 from dagster._core.events import DagsterEvent, EngineEventData, MetadataEntry
@@ -19,7 +21,10 @@ from dagster._core.executor.step_delegating import (
     StepHandler,
     StepHandlerContext,
 )
-from dagster._utils import frozentags, merge_dicts
+from dagster._utils import frozentags
+from dagster._utils.merger import merge_dicts
+
+from dagster_k8s.launcher import K8sRunLauncher
 
 from .client import DagsterKubernetesClient
 from .container_context import K8sContainerContext
@@ -41,8 +46,10 @@ from .job import (
             "max_concurrent": Field(
                 IntSource,
                 is_required=False,
-                description="Limit on the number of pods that will run concurrently within the scope "
-                "of a Dagster run. Note that this limit is per run, not global.",
+                description=(
+                    "Limit on the number of pods that will run concurrently within the scope "
+                    "of a Dagster run. Note that this limit is per run, not global."
+                ),
             ),
             "tag_concurrency_limits": get_tag_concurrency_limits_config(),
         },
@@ -86,12 +93,13 @@ def k8s_job_executor(init_context: InitExecutorContext) -> Executor:
     Configuration set using `tags` on a `@job` will only apply to the `run` level. For configuration
     to apply at each `step` it must be set using `tags` for each `@op`.
     """
-
     run_launcher = init_context.instance.run_launcher
     if not isinstance(run_launcher, K8sRunLauncher):
         raise DagsterUnmetExecutorRequirementsError(
-            "This engine is only compatible with a K8sRunLauncher; configure the "
-            "K8sRunLauncher on your instance to use it.",
+            (
+                "This engine is only compatible with a K8sRunLauncher; configure the "
+                "K8sRunLauncher on your instance to use it."
+            ),
         )
 
     exc_cfg = init_context.executor_config
