@@ -2,9 +2,12 @@ import sys
 from typing import Any, Mapping, Optional, Sequence
 
 import kubernetes
-
-from dagster import Field, MetadataEntry, StringSource
-from dagster import _check as check
+from dagster import (
+    Field,
+    MetadataEntry,
+    StringSource,
+    _check as check,
+)
 from dagster._cli.api import ExecuteRunArgs
 from dagster._core.events import EngineEventData
 from dagster._core.launcher import LaunchRunContext, ResumeRunContext, RunLauncher
@@ -13,8 +16,8 @@ from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus
 from dagster._core.storage.tags import DOCKER_IMAGE_TAG
 from dagster._grpc.types import ResumeRunArgs
 from dagster._serdes import ConfigurableClass, ConfigurableClassData
-from dagster._utils import merge_dicts
 from dagster._utils.error import serializable_error_info_from_exc_info
+from dagster._utils.merger import merge_dicts
 
 from .client import DagsterKubernetesClient
 from .container_context import K8sContainerContext
